@@ -44,11 +44,18 @@ async def authorize(
     prompt: Optional[str] = Depends(get_authorize_prompt),
     screen: str = Depends(get_authorize_screen),
     state: Optional[str] = Query(None),
+    nonce: Optional[str] = Query(None),
+    max_age: Optional[int] = Query(None),
     authentication_flow: AuthenticationFlow = Depends(get_authentication_flow),
     session_token: Optional[SessionToken] = Depends(get_session_token),
 ):
     tenant = client.tenant
-    if session_token is not None and prompt != "login":
+    has_valid_session = False
+    has_valid_session = session_token is not None and (
+        max_age is None or int(session_token.created_at.timestamp()) > max_age
+    )
+
+    if has_valid_session and prompt != "login":
         redirection = tenant.url_for(request, "auth:consent.get")
     elif screen == "register":
         redirection = tenant.url_for(request, "register:get")
@@ -62,6 +69,7 @@ async def authorize(
         redirect_uri=redirect_uri,
         scope=scope,
         state=state,
+        nonce=nonce,
         client=client,
     )
 
@@ -136,7 +144,9 @@ async def get_consent(
         response = await authentication_flow.get_authorization_code_success_redirect(
             login_session.redirect_uri,
             login_session.scope,
+            session_token.created_at,
             login_session.state,
+            login_session.nonce,
             login_session.client,
             user_id,
         )
@@ -180,7 +190,9 @@ async def post_consent(
         response = await authentication_flow.get_authorization_code_success_redirect(
             login_session.redirect_uri,
             login_session.scope,
+            session_token.created_at,
             login_session.state,
+            login_session.nonce,
             login_session.client,
             user_id,
         )
