@@ -1,8 +1,9 @@
 import secrets
-from typing import List
+from datetime import datetime
+from typing import List, Optional
 
 from pydantic import UUID4
-from sqlalchemy import Column, ForeignKey
+from sqlalchemy import TIMESTAMP, Column, ForeignKey
 from sqlalchemy.orm import relationship
 from sqlalchemy.sql.sqltypes import JSON, String
 
@@ -24,6 +25,8 @@ class AuthorizationCode(UUIDModel, CreatedUpdatedAt, WorkspaceBase):
     )
     redirect_uri: str = Column(String(length=2048), nullable=False)
     scope: List[str] = Column(JSON, nullable=False, default=list)
+    authenticated_at: datetime = Column(TIMESTAMP(timezone=True), nullable=False)
+    nonce: Optional[str] = Column(String(length=255), nullable=True)
 
     user_id: UUID4 = Column(GUID, ForeignKey(User.id, ondelete="CASCADE"), nullable=False)  # type: ignore
     user: User = relationship("User")
