@@ -39,6 +39,7 @@ class AuthenticationFlow:
         redirect_uri: str,
         scope: List[str],
         state: Optional[str],
+        nonce: Optional[str],
         client: Client,
     ) -> ResponseType:
         login_session = LoginSession(
@@ -46,6 +47,7 @@ class AuthenticationFlow:
             redirect_uri=redirect_uri,
             scope=scope,
             state=state,
+            nonce=nonce,
             client_id=client.id,
         )
         login_session = await self.login_session_manager.create(login_session)
@@ -107,7 +109,9 @@ class AuthenticationFlow:
         self,
         redirect_uri: str,
         scope: List[str],
+        authenticated_at: datetime,
         state: Optional[str],
+        nonce: Optional[str],
         client: Client,
         user_id: UUID4,
     ) -> RedirectResponse:
@@ -115,6 +119,8 @@ class AuthenticationFlow:
             AuthorizationCode(
                 redirect_uri=redirect_uri,
                 scope=scope,
+                authenticated_at=authenticated_at,
+                nonce=nonce,
                 user_id=user_id,
                 client_id=client.id,
             )
